      subroutine set_vpr20_params( base_name, t_scale,
     &        zmf, zgf, gmf, grf, gng, tlag_fac, tige1_fac,
     &        t1, t2, ntog, t1im, t2im, ntimg,
     &        t1ge1, t2ge1, ntge1, t1ge2, t2ge2, ntge2,
     &        kmax, dtfac, eps_err, h1, hmin, vcdotsc, vbdotsb, 
     &        rte0, rte0_edr, rte0_n2,
     &        rte1, rte1_edr, rte1_n2,
     &        rte2, rte2_edr, rte2_n2,
     &        aeff_b, aeff_s, a_particle, a_db, a_grav, alink,
     &        a_ige_nge, a_ci, ceject, cke, teject1, teject2, 
     &        zeject, secdk, secdiff )

      implicit none

      real    zmf, zgf, gmf, grf, gng, tlag_fac, tige1_fac,
     &        t1, t2, ntog, t1im, t2im, ntimg,
     &        t1ge1, t2ge1, ntge1, t1ge2, t2ge2, ntge2, kmax, dtfac,
     &        eps_err, h1, hmin, vcdotsc, vbdotsb, 
     &        rte0, rte0_edr, rte0_n2,
     &        rte1, rte1_edr, rte1_n2,
     &        rte2, rte2_edr, rte2_n2,
     &        aeff_b, aeff_s, a_particle, a_db, a_grav, alink,
     &        a_ige_nge, a_ci, ceject, cke, teject1, teject2, 
     &        zeject, secdk, secdiff, t_scale
      character(80) base_name

      zmf      =     1.500000
      zgf      =     1.000000
      gmf      =     0.350000
      grf      =     0.400000
      gng      =    45.000000
      t1       =     0.000000
      t2       =    12.0*t_scale
      ntog     =  -(nint(10.0*t2/t_scale) + 1)
      t1im     =     0.000000
      t2im     =     6.0*t_scale
      ntimg    =  -(nint(10.0*t2im/t_scale) + 1)
      t1ge1    =     0.000000
      t2ge1    =     6.0*t_scale
      ntge1    =   (nint(10.0*t2ge1/t_scale) + 1)
      t1ge2    =     0.000000
      t2ge2    =     6.0*t_scale
      ntge2    =   (nint(10.0*t2ge2/t_scale) + 1)
      kmax     = 20000.000000
      dtfac    =     1.00e-02
      eps_err  =     1.00e-04
      h1       =     1.00e-02
      hmin     =     1.00e-10

!  linear model parameters (only used when linear=1): 
!  tlag_fac: time-lag factor for onset of IGE1 after rebound
!  tige1_fac: duration of IGE1 phase
      tlag_fac =     0.2
      tige1_fac =    2.0
!  base entrainment coefficients
      rte0     =     0.010000
      rte1     =    -0.025000
      rte2     =     0.000000
!  EDR* entrainment coefficients
      rte0_edr =     0.400000
      rte1_edr =     0.200000
      rte2_edr =     0.000000
!  N*^2 entrainment coefficients
      rte0_n2  =     0.150000
      rte1_n2  =     0.030000
      rte2_n2  =     0.000000
!  gravity toggle
      a_grav   =     1.0
!  internal structure coefficient et al.
      a_ci     =     0.2
      vcdotsc  =     1.0
      vbdotsb  =     1.0
!  fred proctor linking termcient et al.
      alink    =     0.0
!  ige flag
      a_ige_nge=     1.0
!  effective areas for baroclinic term and for shear gradient
      aeff_b   =     0.4
      aeff_s   =     0.4
      a_db     =     0.000000
!  ideally this should be the same as rte2 above
      a_particle = rte2
!  additional model parameters for the ige model?
      ceject  = 0.02*0. + 0.01*0. + 50.*0. + 0.8
      cke     = 150.*0. + 120.*0. + 5.
      teject1 = 0.05
      teject2 = 0.05
      zeject  = 3.0
      secdk   = 0.10 
      secdiff = 0.03

c   *** write the model parameters to a file

      open(unit=24,file='Output/'//trim(base_name)//'.vpr20_params')

10    format(a12,1p,e12.4)
      write(24,10) 'zmf       = ', zmf
      write(24,10) 'zgf       = ', zgf
      write(24,10) 'gmf       = ', gmf
      write(24,10) 'grf       = ', grf
      write(24,10) 'gng       = ', gng
      write(24,10) 't1        = ', t1
      write(24,10) 't2        = ', t2
      write(24,10) 'ntog      = ', ntog
      write(24,10) 't1im      = ', t1im
      write(24,10) 't2im      = ', t2im
      write(24,10) 'ntimg     = ', ntimg
      write(24,10) 't1ge1     = ', t1ge1
      write(24,10) 't2ge1     = ', t2ge1
      write(24,10) 'ntge1     = ', ntge1
      write(24,10) 't1ge2     = ', t1ge1
      write(24,10) 't2ge2     = ', t2ge2
      write(24,10) 'ntge2     = ', ntge2
      write(24,10) 'kmax      = ', kmax
      write(24,10) 'dtfac     = ', dtfac
      write(24,10) 'eps_err   = ', eps_err
      write(24,10) 'h1        = ', h1
      write(24,10) 'hmin      = ', hmin
      write(24,10) 'rte0      = ', rte0
      write(24,10) 'rte1      = ', rte1
      write(24,10) 'rte2      = ', rte2
      write(24,10) 'rte0_edr  = ', rte0_edr
      write(24,10) 'rte1_edr  = ', rte1_edr
      write(24,10) 'rte2_edr  = ', rte2_edr
      write(24,10) 'rte0_n2   = ', rte0_n2 
      write(24,10) 'rte1_n2   = ', rte1_n2 
      write(24,10) 'rte2_n2   = ', rte2_n2 
      write(24,10) 'vcdotsc   = ', vcdotsc
      write(24,10) 'vbdotsb   = ', vbdotsb
      write(24,10) 'aeff_b    = ', aeff_b
      write(24,10) 'aeff_s    = ', aeff_s
      write(24,10) 'a_db      = ', a_db
      write(24,10) 'ceject    = ', ceject 
      write(24,10) 'cke       = ', cke 
      write(24,10) 'teject1   = ', teject1
      write(24,10) 'teject2   = ', teject2
      write(24,10) 'zeject    = ', zeject
      write(24,10) 'secdk     = ', secdk
      write(24,10) 'secdiff   = ', secdiff
      write(24,10) 'tlag_fac  = ', tlag_fac
      write(24,10) 'tige1_fac = ', tige1_fac

      close(24)

      return
      end
